==> giggle-0.4.90.tar.bz2: giggle-0.4.90/libgiggle/giggle-enums.c <==

/* Generated data (by glib-mkenums) */

#include "giggle-enums.h"
/* enumerations from "giggle-configuration.h" */
#include "giggle-configuration.h"
GType
giggle_configuration_field_get_type(void) {
	static GType etype = 0;
	if(!etype) {
		static const GEnumValue values[] = {
			{CONFIG_FIELD_NAME, "CONFIG_FIELD_NAME", "name"},
			{CONFIG_FIELD_EMAIL, "CONFIG_FIELD_EMAIL", "email"},
			{CONFIG_FIELD_MAIN_WINDOW_MAXIMIZED, "CONFIG_FIELD_MAIN_WINDOW_MAXIMIZED", "main-window-maximized"},
			{CONFIG_FIELD_MAIN_WINDOW_GEOMETRY, "CONFIG_FIELD_MAIN_WINDOW_GEOMETRY", "main-window-geometry"},
			{CONFIG_FIELD_MAIN_WINDOW_VIEW, "CONFIG_FIELD_MAIN_WINDOW_VIEW", "main-window-view"},
			{CONFIG_FIELD_SHOW_GRAPH, "CONFIG_FIELD_SHOW_GRAPH", "show-graph"},
			{CONFIG_FIELD_FILE_VIEW_PATH, "CONFIG_FIELD_FILE_VIEW_PATH", "file-view-path"},
			{CONFIG_FIELD_FILE_VIEW_HPANE_POSITION, "CONFIG_FIELD_FILE_VIEW_HPANE_POSITION", "file-view-hpane-position"},
			{CONFIG_FIELD_FILE_VIEW_VPANE_POSITION, "CONFIG_FIELD_FILE_VIEW_VPANE_POSITION", "file-view-vpane-position"},
			{CONFIG_FIELD_HISTORY_VIEW_VPANE_POSITION, "CONFIG_FIELD_HISTORY_VIEW_VPANE_POSITION", "history-view-vpane-position"},
			{0, NULL, NULL}
		};

		etype = g_enum_register_static("GiggleConfigurationField", values);
	}
	
	return etype;
}
/* enumerations from "giggle-git-list-files.h" */
#include "giggle-git-list-files.h"
GType
giggle_git_list_files_status_get_type(void) {
	static GType etype = 0;
	if(!etype) {
		static const GEnumValue values[] = {
			{GIGGLE_GIT_FILE_STATUS_OTHER, "GIGGLE_GIT_FILE_STATUS_OTHER", "other"},
			{GIGGLE_GIT_FILE_STATUS_CACHED, "GIGGLE_GIT_FILE_STATUS_CACHED", "cached"},
			{GIGGLE_GIT_FILE_STATUS_UNMERGED, "GIGGLE_GIT_FILE_STATUS_UNMERGED", "unmerged"},
			{GIGGLE_GIT_FILE_STATUS_DELETED, "GIGGLE_GIT_FILE_STATUS_DELETED", "deleted"},
			{GIGGLE_GIT_FILE_STATUS_CHANGED, "GIGGLE_GIT_FILE_STATUS_CHANGED", "changed"},
			{GIGGLE_GIT_FILE_STATUS_KILLED, "GIGGLE_GIT_FILE_STATUS_KILLED", "killed"},
			{0, NULL, NULL}
		};

		etype = g_enum_register_static("GiggleGitListFilesStatus", values);
	}
	
	return etype;
}
/* enumerations from "giggle-remote.h" */
#include "giggle-remote.h"
GType
giggle_remote_mechanism_get_type(void) {
	static GType etype = 0;
	if(!etype) {
		static const GEnumValue values[] = {
			{GIGGLE_REMOTE_MECHANISM_GIT, "GIGGLE_REMOTE_MECHANISM_GIT", "git"},
			{GIGGLE_REMOTE_MECHANISM_GIT_SVN, "GIGGLE_REMOTE_MECHANISM_GIT_SVN", "git-svn"},
			{GIGGLE_REMOTE_MECHANISM_INVALID, "GIGGLE_REMOTE_MECHANISM_INVALID", "invalid"},
			{0, NULL, NULL}
		};

		etype = g_enum_register_static("GiggleRemoteMechanism", values);
	}
	
	return etype;
}
/* enumerations from "giggle-remote-branch.h" */
#include "giggle-remote-branch.h"
GType
giggle_remote_direction_get_type(void) {
	static GType etype = 0;
	if(!etype) {
		static const GEnumValue values[] = {
			{GIGGLE_REMOTE_DIRECTION_PUSH, "GIGGLE_REMOTE_DIRECTION_PUSH", "push"},
			{GIGGLE_REMOTE_DIRECTION_PULL, "GIGGLE_REMOTE_DIRECTION_PULL", "pull"},
			{0, NULL, NULL}
		};

		etype = g_enum_register_static("GiggleRemoteDirection", values);
	}
	
	return etype;
}

/* Generated data ends here */

==> giggle-0.4.91.tar.bz2: giggle-0.4.91/libgiggle/giggle-enums.c <==

/* Generated data (by glib-mkenums) */

#include "giggle-enums.h"
/* enumerations from "giggle-error.h" */
#include "giggle-error.h"
GType
giggle_error_get_type(void) {
	static GType etype = 0;
	if(!etype) {
		static const GEnumValue values[] = {
			{GIGGLE_ERROR_DISPATCH_COMMAND_NOT_FOUND, "GIGGLE_ERROR_DISPATCH_COMMAND_NOT_FOUND", "found"},
			{0, NULL, NULL}
		};

		etype = g_enum_register_static("GiggleError", values);
	}
	
	return etype;
}
/* enumerations from "giggle-plugin.h" */
#include "giggle-plugin.h"
GType
giggle_plugin_error_get_type(void) {
	static GType etype = 0;
	if(!etype) {
		static const GEnumValue values[] = {
			{GIGGLE_PLUGIN_ERROR_NONE, "GIGGLE_PLUGIN_ERROR_NONE", "none"},
			{GIGGLE_PLUGIN_ERROR_MALFORMED, "GIGGLE_PLUGIN_ERROR_MALFORMED", "malformed"},
			{0, NULL, NULL}
		};

		etype = g_enum_register_static("GigglePluginError", values);
	}
	
	return etype;
}
/* enumerations from "giggle-remote.h" */
#include "giggle-remote.h"
GType
giggle_remote_mechanism_get_type(void) {
	static GType etype = 0;
	if(!etype) {
		static const GEnumValue values[] = {
			{GIGGLE_REMOTE_MECHANISM_GIT, "GIGGLE_REMOTE_MECHANISM_GIT", "git"},
			{GIGGLE_REMOTE_MECHANISM_GIT_SVN, "GIGGLE_REMOTE_MECHANISM_GIT_SVN", "git-svn"},
			{GIGGLE_REMOTE_MECHANISM_INVALID, "GIGGLE_REMOTE_MECHANISM_INVALID", "invalid"},
			{0, NULL, NULL}
		};

		etype = g_enum_register_static("GiggleRemoteMechanism", values);
	}
	
	return etype;
}
/* enumerations from "giggle-remote-branch.h" */
#include "giggle-remote-branch.h"
GType
giggle_remote_direction_get_type(void) {
	static GType etype = 0;
	if(!etype) {
		static const GEnumValue values[] = {
			{GIGGLE_REMOTE_DIRECTION_PUSH, "GIGGLE_REMOTE_DIRECTION_PUSH", "push"},
			{GIGGLE_REMOTE_DIRECTION_PULL, "GIGGLE_REMOTE_DIRECTION_PULL", "pull"},
			{0, NULL, NULL}
		};

		etype = g_enum_register_static("GiggleRemoteDirection", values);
	}
	
	return etype;
}
/* enumerations from "giggle-searchable.h" */
#include "giggle-searchable.h"
GType
giggle_search_direction_get_type(void) {
	static GType etype = 0;
	if(!etype) {
		static const GEnumValue values[] = {
			{GIGGLE_SEARCH_DIRECTION_NEXT, "GIGGLE_SEARCH_DIRECTION_NEXT", "next"},
			{GIGGLE_SEARCH_DIRECTION_PREV, "GIGGLE_SEARCH_DIRECTION_PREV", "prev"},
			{0, NULL, NULL}
		};

		etype = g_enum_register_static("GiggleSearchDirection", values);
	}
	
	return etype;
}

/* Generated data ends here */
